svg_maker library

Classes

AnimationElement
Base animation element class.
DescriptiveElement
Base descriptive element class.
ShapeElement
Base shape element class.
Svg
SvgAnimate
Class used to animate an attribute of an element over time.
SvgAnimateMotion
Class used to define how an element moves along a motion path.
SvgAnimateTransform
Class used to animate a transformation attribute on its target element.
SvgCircle
Class used to draw circles based on a center point and a radius.
SvgDefaultValues
SvgDesc
Class used to provide an accessible, long-text description of any svg.
SvgElement
SvgEllipse
Class used to draw ellipses based on a center coordinate, and both their x and y radius.
SvgLine
Class used to draw a line connecting two points.
SvgMetadata
Class used to add metadata to svg content.
SvgMpath
Class used as sub-element for SvgAnimateMotion.
SvgPath
Class used to draw a generic shape. All the basic shapes can be created with a path element.
SvgPoint
SvgPolygon
Class used to draw a closed shape consisting of a set of connected straight line segments. The last point is connected to the first point.
SvgPolyline
Class used to draw open shapes as the last point doesn't have to be connected to the first point.
SvgRect
Class used to draw rectangles, defined by their position, width, and height.
SvgSet
Class used to set the value of an attribute for a specified duration.
SvgText
SvgTextPath
SvgTitle
Class used to provide an accessible, short-text description of any svg.
SvgTspan
TextContentChildElement
TextContentElement

Extensions

ColorExtension on Color