SvgTextPath class

Inheritance

Constructors

SvgTextPath()

Properties

fill Color
Sets color used to paint the element.
no getterinherited
fontFamily String
Sets font family that will be used to render the text.
no getterinherited
fontSize String
Sets the size of the font from baseline to baseline.
no getterinherited
fontSizeAdjust String
Sets an aspect value for an element that will preserve the x-height of the first choice font in a substitute font.
no getterinherited
fontStyle FontStyleValue
Sets style used to render text (normal, italic, or oblique).
no getterinherited
fontVariant String
Sets variations of the font's glyphs used to render text.
no getterinherited
fontWeight String
Sets boldness or lightness of the glyphs used to render the text.
no getterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stroke Color
Sets color used to paint the outline of the shape.
no getterinherited
strokeDasharray List<int>
Sets the pattern of dashes and gaps used to paint the outline of the shape.
no getterinherited
strokeDashoffset String
Sets the offset on the rendering of the associated dash array.
no getterinherited
strokeOpacity String
no getterinherited
strokeWidth String
no getterinherited
style String
Sets the style of the element using CSS declarations.
no getterinherited
textAnchor TextAnchorValue
Sets the alignment of a string of pre-formatted text.
no getterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stringify(StringBuffer sBuffer) → void
Returns string representation of svg element.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited