fontSizeAdjust property

set fontSizeAdjust (String fontSizeAdjust)

Sets an aspect value for an element that will preserve the x-height of the first choice font in a substitute font.

Implementation

set fontSizeAdjust(String fontSizeAdjust) {
  _attributes[SvgAttribute.fontSizeAdjust] = fontSizeAdjust;
}