SvgPolyline class
Class used to draw open shapes as the last point doesn't have to be connected to the first point.
- Inheritance
-
- Object
- SvgElement
- ShapeElement
- SvgPolyline
- Mixed-in types
Constructors
Properties
- fill ← Color
-
Sets color used to paint the element.
no getterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setteroverride
- pathLength ← num
-
Sets the total length of the shape.
no getterinherited
-
points
← List<
SvgPoint> -
Sets the list of points (pairs of x,y absolute coordinates) required to draw the polygon.
no getterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stroke ← Color
-
Sets color used to paint the outline of the shape.
no getterinherited
-
strokeDasharray
← List<
int> -
Sets the pattern of dashes and gaps used to paint the outline of the shape.
no getterinherited
- strokeDashoffset ← String
-
Sets the offset on the rendering of the associated dash array.
no getterinherited
- strokeOpacity ← String
-
no getterinherited
- strokeWidth ← String
-
no getterinherited
- style ← String
-
Sets the style of the element using CSS declarations.
no getterinherited
Methods
-
addPoint(
SvgPoint point) → void -
Add a point (pair of x,y absolute coordinate) to list.
inherited
-
addPoints(
Iterable< SvgPoint> points) → void -
Adds a list/set of points (pairs of x,y absolute coordinates) to list.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stringify(
StringBuffer sBuffer) → void -
Returns string representation of svg element.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited